--- a/arch/arm/boot/dts/kirkwood-blackarmor-nas220.dts
+++ b/arch/arm/boot/dts/kirkwood-blackarmor-nas220.dts
@@ -17,6 +17,13 @@
 	compatible = "seagate,blackarmor-nas220","marvell,kirkwood-88f6192",
 		     "marvell,kirkwood";
 
+	aliases {
+		led-boot = &led_status_amber;
+		led-failsafe = &led_status_amber;
+		led-running = &led_status_blue;
+		led-upgrade = &led_status_amber;
+	};
+
 	memory { /* 128 MB */
 		device_type = "memory";
 		reg = <0x00000000 0x8000000>;
@@ -36,14 +43,14 @@
 		compatible = "gpio-keys";
 
 		reset {
-			label = "Reset";
-			linux,code = <KEY_POWER>;
+			label = "Reset Button";
+			linux,code = <KEY_RESTART>;
 			gpios = <&gpio0 29 GPIO_ACTIVE_HIGH>;
 		};
 
-		button {
-			label = "Power";
-			linux,code = <KEY_SLEEP>;
+		power {
+			label = "Power Button";
+			linux,code = <KEY_POWER>;
 			gpios = <&gpio0 26 GPIO_ACTIVE_LOW>;
 		};
 	};
@@ -51,11 +58,27 @@
 	gpio-leds {
 		compatible = "gpio-leds";
 
-		blue-power {
+		led_power_blue: power_blue {
 			label = "nas220:blue:power";
 			gpios = <&gpio0 12 GPIO_ACTIVE_HIGH>;
 			linux,default-trigger = "default-on";
 		};
+
+		disk_blue {
+			label = "nas220:blue:disk";
+			gpios = <&gpio0 16 GPIO_ACTIVE_LOW>;
+			linux,default-trigger = "disk-activity";
+		};
+
+		led_status_blue: status_blue {
+			label = "nas220:blue:status";
+			gpios = <&gpio0 23 GPIO_ACTIVE_HIGH>;
+		};
+
+		led_status_amber: status_amber {
+			label = "nas220:amber:status";
+			gpios = <&gpio0 22 GPIO_ACTIVE_HIGH>;
+		};
 	};
 
 	regulators {
@@ -153,6 +176,33 @@
 
 &nand {
 	status = "okay";
+
+	partitions {
+		compatible = "fixed-partitions";
+
+		partition@0 {
+			label = "uboot";
+			reg = <0x0 0xa0000>;
+			read-only;
+		};
+
+		partition@a0000 {
+			label = "uboot-env";
+			reg = <0xa0000 0x10000>;
+			read-only;
+		};
+
+		partition@b0000 {
+			label = "reserved";
+			reg = <0xb0000 0x10000>;
+			read-only;
+		};
+
+		partition@c0000 {
+			label = "ubi";
+			reg = <0xc0000 0x1e80000>;
+		};
+	};
 };
 
 &mdio {
